@@ -20,6 +20,18 @@
 # For any question, feature requests or bug reports, feel free to contact me at:
 # knx at aminate dot net
 
+"""
+USAGE:
+	pyknxcommunicator.py [-l linknxaddress] [-c communicatoraddress] -f userfile
+
+OPTIONS:
+    -l --linknx-addr  Address of the linknx daemon. This must be of the form <hostname:port> of <ipaddress:port>. Default is localhost:1028
+    -c --comm-addr    Address the communicator will bind to. This must be of the form <hostname:port> of <ipaddress:port>. Default is localhost:1029
+    -f --user-file    Filename of the python script that implement the callbacks specified in linknx XML configuration.
+       --verbose      Verbosity level, amongst [debug, info, warning, error]. Default is info.
+       --help         Display this help message and exit.
+"""
+
 import sys
 import getopt
 import signal
@@ -34,16 +46,7 @@ def signal_handler(signal, frame):
 	communicator.stopListening()
 
 def printUsage():
-	scriptName = 'pyknxcommunicator.py'
-	print 'USAGE:'
-	print scriptName + ' [-l linknxaddress] [-c communicatoraddress] -f userfile'
-	print ''
-	print 'OPTIONS:'
-	print '\t-l --linknx-addr			 Address of the linknx daemon. This must be of the form <hostname:port> of <ipaddress:port>. Default is localhost:1028'
-	print '\t-c --comm-addr				 Address the communicator will bind to. This must be of the form <hostname:port> of <ipaddress:port>. Default is localhost:1029'
-	print '\t-f --user-file				 Filename of the python script that implement the callbacks specified in linknx XML configuration.'
-	print '\t   --verbose				 Verbosity level, amongst [debug, info, warning, error]. Default is info.'
-	print '\t--help						 Display this help message and exit.'
+	print __doc__
 
 def parseAddress(addrStr, option):
 	ix = addrStr.find(':')
